@@ -46,6 +46,8 @@ gvmd --create-user=$USER --password=$PASSWORD || true
 # set the feed import owner
 uid=$(gvmd --get-users --verbose | grep "^$USER " | awk '{print $2}')
 gvmd --modify-setting 78eceaec-3385-11ea-b237-28d24461215b --value "$uid"
+# set the agent owner
+gvmd --modify-setting 1ee1f106-8b2e-461c-b426-7f5d76001b29 --value "$uid"
 
 echo "starting gvmd"
 gvmd $GVMD_ARGS ||
