@@ -12,6 +12,7 @@
 
 #include "gmp_agent_groups.h"
 #include "manage.h"
+#include "manage_acl.h"
 
 #undef G_LOG_DOMAIN
 /**
@@ -79,7 +80,18 @@ get_agent_groups_run (gmp_parser_t *gmp_parser, GError **error)
 
   if (ret)
     {
-      SEND_TO_CLIENT_OR_FAIL (XML_ERROR_SYNTAX ("get_agent_groups", "Permission denied"));
+      switch (ret)
+        {
+        case 99:
+          SEND_TO_CLIENT_OR_FAIL
+           (XML_ERROR_SYNTAX ("get_agent_groups",
+                              "Permission denied"));
+          break;
+        default:
+          internal_error_send_to_client (error);
+          get_agent_groups_reset ();
+          return;
+        }
       get_agent_groups_reset ();
       return;
     }
@@ -276,6 +288,14 @@ create_agent_group_run (gmp_parser_t *gmp_parser, GError **error)
   agent_uuid_list_t agent_uuids = NULL;
   agent_group_t new_agent_group;
 
+  if (!acl_user_may ("create_agent_group"))
+    {
+      SEND_TO_CLIENT_OR_FAIL (XML_ERROR_SYNTAX ("create_agent_group",
+                              "Permission denied"));
+      create_agent_group_reset ();
+      return;
+    }
+
   root = (entity_t) create_agent_group_data.context->first->data;
 
   // Handle copy logic if provided
@@ -439,8 +459,14 @@ create_agent_group_run (gmp_parser_t *gmp_parser, GError **error)
       log_event_fail ("create_agent_group", "Agent Group", NULL, "created");
       break;
 
+    case AGENT_GROUP_RESP_AGENT_UNAUTHORIZED:
+      SEND_TO_CLIENT_OR_FAIL (
+        XML_ERROR_SYNTAX ("create_agent_group", "Unauthorized Agent"));
+      log_event_fail ("agent_group", "Agent Group", NULL, "created");
+      break;
+
     case AGENT_GROUP_RESP_INTERNAL_ERROR:
-      default:
+    default:
         SEND_TO_CLIENT_OR_FAIL (XML_INTERNAL_ERROR ("create_agent_group"));
         log_event_fail ("agent_group", "Agent Group", NULL, "created");
         break;
@@ -573,6 +599,14 @@ modify_agent_group_run (gmp_parser_t *gmp_parser, GError **error)
   entity_t root, name, comment, agents_elem;
   const char *agent_group_uuid, *name_text;
 
+  if (!acl_user_may ("modify_agent_group"))
+    {
+      SEND_TO_CLIENT_OR_FAIL (XML_ERROR_SYNTAX ("modify_agent_group",
+                              "Permission denied"));
+      create_agent_group_reset ();
+      return;
+    }
+
   root = (entity_t) modify_agent_group_data.context->first->data;
 
   agent_group_uuid = entity_attribute (root, "agent_group_id");
@@ -711,6 +745,12 @@ modify_agent_group_run (gmp_parser_t *gmp_parser, GError **error)
         log_event_fail ("agent_group", "Agent Group", NULL, "modified");
         break;
 
+      case AGENT_GROUP_RESP_AGENT_UNAUTHORIZED:
+        SEND_TO_CLIENT_OR_FAIL (
+          XML_ERROR_SYNTAX ("modify_agent_group", "Unauthorized Agent"));
+        log_event_fail ("agent_group", "Agent Group", NULL, "modified");
+        break;
+
       case AGENT_GROUP_RESP_INTERNAL_ERROR:
       default:
         SEND_TO_CLIENT_OR_FAIL (XML_INTERNAL_ERROR ("modify_agent_group"));
