@@ -50,6 +50,10 @@
 #include <gvm/util/authutils.h>
 #include <gvm/osp/osp.h>
 
+#if ENABLE_HTTP_SCANNER
+#include "manage_http_scanner.h"
+#endif
+
 #if OPENVASD
 #include <gvm/openvasd/openvasd.h>
 #endif
@@ -63,6 +67,7 @@
 
 #if ENABLE_CONTAINER_SCANNING
 #include "manage_oci_image_targets.h"
+#include "manage_container_image_scanner.h"
 #endif
 
 /**
@@ -627,6 +632,13 @@ agent_group_tasks_exist_by_scanner (scanner_t scanner);
 
 int
 agent_group_hidden_tasks_exist_by_scanner (scanner_t scanner);
+
+agent_group_t
+task_agent_group (task_t);
+
+int
+task_agent_group_in_trash (task_t task);
+
 #endif /* ENABLE_AGENTS */
 
 int
@@ -882,15 +894,9 @@ severity_data_add (severity_data_t*, double);
 void
 severity_data_add_count (severity_data_t*, double, int);
 
-#if CVSS3_RATINGS == 1
 void
 severity_data_level_counts (const severity_data_t*,
                             int*, int*, int*, int*, int*, int*, int*);
-#else
-void
-severity_data_level_counts (const severity_data_t*,
-                            int*, int*, int*, int*, int*, int*);
-#endif
 
 
 /* General task facilities. */
@@ -923,6 +929,7 @@ move_task (const char*, const char*);
   "'AIX Local Security Checks',"                   \
   " 'AlmaLinux Local Security Checks',"            \
   " 'Amazon Linux Local Security Checks',"         \
+  " 'Arch Linux Local Security Checks',"           \
   " 'CentOS Local Security Checks',"               \
   " 'Citrix Xenserver Local Security Checks',"     \
   " 'Debian Local Security Checks',"               \
@@ -959,6 +966,7 @@ move_task (const char*, const char*);
   { "AIX Local Security Checks",                   \
     "AlmaLinux Local Security Checks",             \
     "Amazon Linux Local Security Checks",          \
+    "Arch Linux Local Security Checks",            \
     "CentOS Local Security Checks",                \
     "Debian Local Security Checks",                \
     "Fedora Local Security Checks",                \
@@ -1140,7 +1148,6 @@ int
 report_scan_result_count (report_t, const char*, const char*, int, const char*,
                           const char*, int, int, int*);
 
-#if CVSS3_RATINGS == 1
 int
 report_counts (const char*, int*, int*, int*, int*, int*, int*, double*,
                int, int);
@@ -1148,15 +1155,6 @@ report_counts (const char*, int*, int*, int*, int*, int*, int*, double*,
 int
 report_counts_id (report_t, int*, int*, int*, int*, int*, int*, double*,
                   const get_data_t*, const char*);
-#else
-int
-report_counts (const char*, int*, int*, int*, int*, int*, double*,
-               int, int);
-
-int
-report_counts_id (report_t, int*, int*, int*, int*, int*, double*,
-                  const get_data_t*, const char*);
-#endif
 
 int
 report_counts_id_no_filt (report_t, int*, int*, int*, int*, int*, int*,
@@ -1619,20 +1617,6 @@ prognosis_iterator_description (iterator_t*);
 int
 manage_max_hosts ();
 
-void
-manage_filter_controls (const gchar *, int *, int *, gchar **, int *);
-
-void
-manage_report_filter_controls (const gchar *, int *, int *, gchar **, int *,
-                               int *, gchar **, gchar **, gchar **, gchar **,
-                               gchar **, int *, int *, int *, int *, gchar **);
-
-gchar *
-manage_clean_filter (const gchar *, int);
-
-gchar *
-manage_clean_filter_remove (const gchar *, const gchar *, int);
-
 int
 manage_count_hosts (const char *, const char *);
 
@@ -2480,7 +2464,7 @@ int
 manage_create_scanner (GSList *, const db_conn_info_t *, const char *,
                        const char *, const char *, const char *, const char *,
                        const char *, const char *, const char *,
-                       const char *, const char *);
+                       const char *, const char *, int);
 
 int
 manage_modify_scanner (GSList *, const db_conn_info_t *, const char *,
@@ -2997,85 +2981,6 @@ role_count (const get_data_t*);
 int
 modify_role (const char *, const char *, const char *, const char *);
 
-
-/* Filters. */
-
-/**
- * @brief filt_id value to use term or built-in default filter.
- */
-#define FILT_ID_NONE "0"
-
-/**
- * @brief filt_id value to use the filter in the user setting if possible.
- */
-#define FILT_ID_USER_SETTING "-2"
-
-gboolean
-find_filter (const char*, filter_t*);
-
-gboolean
-find_filter_with_permission (const char*, filter_t*, const char*);
-
-char*
-filter_uuid (filter_t);
-
-char*
-trash_filter_uuid (filter_t);
-
-char*
-filter_name (filter_t);
-
-char*
-trash_filter_name (filter_t);
-
-int
-create_filter (const char*, const char*, const char*, const char*, filter_t*);
-
-int
-copy_filter (const char*, const char*, const char*, filter_t*);
-
-int
-delete_filter (const char *, int);
-
-int
-trash_filter_in_use (filter_t);
-
-int
-filter_in_use (filter_t);
-
-int
-trash_filter_writable (filter_t);
-
-int
-filter_writable (filter_t);
-
-int
-filter_count (const get_data_t*);
-
-int
-init_filter_iterator (iterator_t*, get_data_t*);
-
-const char*
-filter_iterator_type (iterator_t*);
-
-const char*
-filter_iterator_term (iterator_t*);
-
-void
-init_filter_alert_iterator (iterator_t*, filter_t);
-
-const char*
-filter_alert_iterator_name (iterator_t*);
-
-const char*
-filter_alert_iterator_uuid (iterator_t*);
-
-int
-filter_alert_iterator_readable (iterator_t*);
-
-int
-modify_filter (const char*, const char*, const char*, const char*, const char*);
-
 
 /* Schema. */
 
@@ -3772,11 +3677,4 @@ get_vt_verification_collation ();
 void
 set_vt_verification_collation (const char *);
 
-#if OPENVASD
-
-/* openvasd Connection */
-http_scanner_connector_t
-openvasd_scanner_connect (scanner_t, const char *);
-#endif
-
 #endif /* not _GVMD_MANAGE_H */
