@@ -96,4 +96,55 @@ asset_os_iterator_average_severity (iterator_t *);
 int
 asset_os_iterator_all_installs (iterator_t *);
 
+void
+init_host_detail_iterator (iterator_t *, resource_t);
+
+const char*
+host_detail_iterator_name (iterator_t *);
+
+const char*
+host_detail_iterator_value (iterator_t *);
+
+const char*
+host_detail_iterator_source_type (iterator_t *);
+
+const char*
+host_detail_iterator_source_id (iterator_t *);
+
+void
+init_os_host_iterator (iterator_t *, resource_t);
+
+const char*
+os_host_iterator_severity (iterator_t *);
+
+int
+init_resource_names_host_iterator (iterator_t *, get_data_t *);
+
+int
+init_resource_names_os_iterator (iterator_t *, get_data_t *);
+
+int
+asset_iterator_writable (iterator_t *);
+
+int
+asset_iterator_in_use (iterator_t *);
+
+int
+modify_asset (const char *, const char *);
+
+int
+delete_asset (const char *, const char *, int);
+
+int
+asset_host_count (const get_data_t *);
+
+int
+asset_os_count (const get_data_t *);
+
+gchar *
+host_routes_xml (host_t);
+
+int
+add_assets_from_host_in_report (report_t, const char *);
+
 #endif /* not _GVMD_MANAGE_ASSETS_H */
