@@ -780,6 +780,32 @@ agent_id_by_uuid_and_scanner (const gchar *agent_uuid, scanner_t scanner_id,
   return 1; // agent not found
 }
 
+/**
+ * @brief Check if an agent is authorized.
+ *
+ * @param[in] agent_uuid   The UUID of the agent.
+ * @param[in] scanner_id   The scanner row ID.
+ *
+ * @return TRUE if the agent is authorized,
+ *         FALSE if the agent is not authorized.
+ */
+gboolean
+agent_authorized (const gchar *agent_uuid, scanner_t scanner_id)
+{
+  g_return_val_if_fail (agent_uuid != NULL, -1);
+
+  // Check if the given agent is authorized
+  int authorized =
+    sql_int ("SELECT authorized FROM agents "
+             "WHERE uuid = '%s' AND scanner = %llu;",
+             agent_uuid, scanner_id);
+
+  if (authorized == 1)
+    return TRUE; // Authorized
+
+  return FALSE; // Not authorized
+}
+
 /**
  * @brief Check if any agent in the UUID list is currently in use.
  *
