@@ -31,11 +31,16 @@
 #define _FILE_OFFSET_BITS 64
 #include <stdio.h>
 
+#include "manage_http_scanner.h"
 #include "manage_sql.h"
 #include "manage_sql_configs.h"
 #include "manage_sql_nvts_openvasd.h"
 #include "sql.h"
 
+#if ENABLE_CONTAINER_SCANNING
+#include "manage_container_image_scanner.h"
+#endif
+
 #include <gvm/util/jsonpull.h>
 #include <gvm/util/vtparser.h>
 
@@ -321,7 +326,7 @@ update_scanner_preferences_openvasd (scanner_t scan)
   GSList *point;
   GSList *scan_prefs = NULL;
 
-  connector = openvasd_scanner_connect (scan, NULL);
+  connector = http_scanner_connect (scan, NULL);
   if (!connector)
     {
       g_warning ("%s: failed to connect to scanner (%s)", __func__,
@@ -342,6 +347,23 @@ update_scanner_preferences_openvasd (scanner_t scan)
   http_scanner_response_cleanup (resp);
   http_scanner_connector_free (connector);
 
+#if ENABLE_CONTAINER_SCANNING
+
+  connector = container_image_scanner_connect (scan, NULL);
+  if (!connector)
+    {
+      g_warning ("%s: failed to get preferences from container image scanner",
+                 __func__);
+      return -1;
+    }
+
+  http_scanner_parsed_scans_preferences (connector, &scan_prefs);
+  g_debug ("There are %d scan preferences for container image scanner",
+           g_slist_length (scan_prefs));
+  http_scanner_connector_free (connector);
+
+#endif
+
   point = scan_prefs;
   first = 1;
 
@@ -415,7 +437,7 @@ update_nvt_cache_openvasd (gchar *db_feed_version,
   if (scan == 0)
     return -1;
 
-  connector = openvasd_scanner_connect (scan, NULL);
+  connector = http_scanner_connect (scan, NULL);
   if (!connector)
     {
       g_warning ("%s: failed to connect to scanner (%s)", __func__,
@@ -465,7 +487,7 @@ nvts_feed_info_internal_from_openvasd (const gchar *scanner_uuid,
   if (scan == 0)
     return -1;
 
-  connector = openvasd_scanner_connect (scan, NULL);
+  connector = http_scanner_connect (scan, NULL);
   if (!connector)
     return 1;
 
