@@ -17,7 +17,7 @@
  */
 
 /**
- * @file manage_sql_nvts_openvasd.h
+ * @file
  * @brief Manager Manage library: openvasd SQL backend headers.
  */
 
@@ -41,5 +41,8 @@ int
 nvts_feed_version_status_internal_openvasd (gchar **db_feed_version_out,
                                             gchar **scanner_feed_version_out);
 
+int
+update_scanner_preferences_openvasd (scanner_t scanner);
+
 #endif //MANAGE_NVTS_OPENVASD_H
 #endif
